@@ -8,16 +8,21 @@ from joblib import Parallel, delayed, cpu_count
 # local import
 from . import hrf
 
-def create_design_matrix(conditions, onsets, TR, n_scans, basis='dhrf',
-                         oversample=100, hrf_length=30):
+def create_design_matrix(conditions, onsets, TR, n_scans, basis='3hrf',
+                         oversample=100, hrf_length=20):
     """
     Parameters
     ----------
-    conditions:
-    onset:
+    conditions: list of conditions
+    onset: list of onsets
+    TR: float
+        repetition time
+    n_scans: number of scans
     """
-    if basis == 'dhrf':
+    if basis == '3hrf':
         basis = [hrf.spmt, hrf.dspmt, hrf.ddspmt]
+    elif basis == '2hrf':
+        basis = [hrf.spmt, hrf.dspmt]
     elif basis == 'hrf':
         basis = [hrf.spmt]
     elif basis == 'fir':
@@ -143,17 +148,20 @@ def _separate_innerloop(glms_design, n_basis, voxels):
     betas = np.empty((n_basis, glms_design.shape[0], voxels.shape[-1]))
     w = np.empty_like(betas)
     for i in range(glms_design.shape[0]):
-        tmp = linalg.lstsq(glms_design[i], voxels)[0]
+        design = np.concatenate((glms_design[i], np.ones((voxels.shape[0], 1))), axis=1)
+        tmp = linalg.lstsq(design, voxels)[0]
         betas[:, i, :] = tmp[:n_basis]
-        w[:, i, :] = tmp[n_basis:]
+        w[:, i, :] = tmp[n_basis:-1]
     return betas, w
 
 
-def glms_from_glm(glm_design, Q, ref_hrf, n_jobs, return_w, voxels):
+def glms_from_glm(glm_design, Q, n_jobs, return_w, voxels):
     """
     Performs a GLM-separate from a GLM design matrix as input
 
     Needs a numpy array (no sparse matrix) as input
+
+    **Note** output is unnormalized
     """
     n_basis = Q.shape[1]
     glms_design = classic_to_obo(glm_design, n_basis)
@@ -170,19 +178,15 @@ def glms_from_glm(glm_design, Q, ref_hrf, n_jobs, return_w, voxels):
         w.append(o[1])
     full_betas = np.concatenate(betas, axis=1)
     full_w = np.concatenate(w, axis=1)
-    hrfs = full_betas.T.dot(Q.T)
-    sign = np.sign((hrfs * ref_hrf).sum(-1))
-    hrfs = hrfs * sign[..., None]
-    # norm = hrfs.max(-1)
+    hrfs = full_betas.T
     norm = np.sqrt((hrfs * hrfs).sum(-1))
     hrfs /= norm[..., None]
-    betas = norm * sign
+    betas = norm
     if return_w:
         hrfs_w = full_w.T.dot(Q.T)
         norm_w = np.sqrt((hrfs_w * hrfs_w).sum(-1))
-        sign_w = np.sign((hrfs_w * ref_hrf).sum(-1))
-        hrfs_w = hrfs_w * sign[..., None] / norm_w[..., None]
-        betas_w = norm_w * sign_w
+        hrfs_w = hrfs_w  / norm_w[..., None]
+        betas_w = norm_w
         return hrfs.T, betas.T, betas_w.T
     return hrfs.T, betas.T
 
